==> acornlib-1.21.1-r7-sources.jar: net/acoyt/acornlib/api/item/AcornItemSettings.java <==
package net.acoyt.acornlib.api.item;

import net.acoyt.acornlib.impl.component.HitParticleComponent;
import net.acoyt.acornlib.impl.component.HitSoundComponent;
import net.acoyt.acornlib.impl.component.SweepParticleComponent;
import net.acoyt.acornlib.impl.init.AcornComponents;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3902;

@SuppressWarnings("unused")
public class AcornItemSettings extends class_1792.class_1793 {
    public AcornItemSettings twoHanded() {
        this.method_57349(AcornComponents.TWO_HANDED, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings followsCam() {
        this.method_57349(AcornComponents.FOLLOWS_CAM, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings showHand() {
        this.method_57349(AcornComponents.SHOW_HAND, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings undroppable() {
        this.method_57349(AcornComponents.UNDROPPABLE, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings skin(String skin) {
        this.method_57349(AcornComponents.SKIN, skin);
        return this;
    }

    public AcornItemSettings hitParticle(class_2960 particle) {
        this.method_57349(AcornComponents.HIT_PARTICLE, new HitParticleComponent(particle, 0));
        return this;
    }

    public AcornItemSettings hitParticle(class_2960 particle, int count) {
        this.method_57349(AcornComponents.HIT_PARTICLE, new HitParticleComponent(particle, count));
        return this;
    }

    public AcornItemSettings hitSound(class_3414 soundEvent) {
        this.method_57349(AcornComponents.HIT_SOUND, new HitSoundComponent(soundEvent.method_14833(), false));
        return this;
    }

    public AcornItemSettings hitSound(class_3414 soundEvent, boolean randomPitch) {
        this.method_57349(AcornComponents.HIT_SOUND, new HitSoundComponent(soundEvent.method_14833(), randomPitch));
        return this;
    }

    public AcornItemSettings sweepParticle(int base, int shadow) {
        this.method_57349(AcornComponents.SWEEP_PARTICLE, new SweepParticleComponent(base, shadow));
        return this;
    }
}

==> acornlib-1.21.8-r5-sources.jar: net/acoyt/acornlib/api/item/AcornItemSettings.java <==
package net.acoyt.acornlib.api.item;

import net.acoyt.acornlib.impl.component.HitParticleComponent;
import net.acoyt.acornlib.impl.component.HitSoundComponent;
import net.acoyt.acornlib.impl.component.SweepParticleComponent;
import net.acoyt.acornlib.impl.init.AcornComponents;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3902;

@SuppressWarnings("unused")
public class AcornItemSettings extends class_1792.class_1793 {
    public AcornItemSettings twoHanded() {
        this.method_57349(AcornComponents.TWO_HANDED, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings followsCam() {
        this.method_57349(AcornComponents.FOLLOWS_CAM, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings showHand() {
        this.method_57349(AcornComponents.SHOW_HAND, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings undroppable() {
        this.method_57349(AcornComponents.UNDROPPABLE, class_3902.field_17274);
        return this;
    }

    public AcornItemSettings skin(String skin) {
        this.method_57349(AcornComponents.SKIN, skin);
        return this;
    }

    public AcornItemSettings secondaryModel(class_2960 modelId) {
        this.method_57349(AcornComponents.SECONDARY_MODEL, modelId);
        return this;
    }

    public AcornItemSettings tertiaryModel(class_2960 modelId) {
        this.method_57349(AcornComponents.TERTIARY_MODEL, modelId);
        return this;
    }

    public AcornItemSettings hitParticle(class_2960 particle) {
        this.method_57349(AcornComponents.HIT_PARTICLE, new HitParticleComponent(particle, 0));
        return this;
    }

    public AcornItemSettings hitParticle(class_2960 particle, int count) {
        this.method_57349(AcornComponents.HIT_PARTICLE, new HitParticleComponent(particle, count));
        return this;
    }

    public AcornItemSettings hitSound(class_3414 soundEvent) {
        this.method_57349(AcornComponents.HIT_SOUND, new HitSoundComponent(soundEvent.comp_3319(), false));
        return this;
    }

    public AcornItemSettings hitSound(class_3414 soundEvent, boolean randomPitch) {
        this.method_57349(AcornComponents.HIT_SOUND, new HitSoundComponent(soundEvent.comp_3319(), randomPitch));
        return this;
    }

    public AcornItemSettings sweepParticle(int base, int shadow) {
        this.method_57349(AcornComponents.SWEEP_PARTICLE, new SweepParticleComponent(base, shadow));
        return this;
    }
}
